@@ -13,6 +13,8 @@ The work of MAD!
 %
 Made in the USA!
 %
+Celestial!
+%
 Asynchronous!
 %
 Seasons!
@@ -33,6 +35,8 @@ Fluid simulations!
 %
 Whoo, Bukkit!
 %
+Whoo, Charged Miners!
+%
 Whoo, Mineflayer!
 %
 Whoo, Mineserver!
