@@ -67,7 +67,7 @@ class BetaServerProtocol(object, Protocol):
 
     def __init__(self):
         self.chunks = dict()
-        self.windows = dict()
+        self.windows = []
         self.wid = 1
 
         self.location = Location()
@@ -325,15 +325,22 @@ class BetaServerProtocol(object, Protocol):
 
         pass
 
-    # Convenience methods
+    # Convenience methods for consolidating code and expressing intent. I
+    # hear that these are occasionally useful.
+
+    def write_packet(self, header, **payload):
+        """
+        Send a packet to the client.
+        """
+
+        self.transport.write(make_packet(header, **payload))
 
     def update_ping(self):
         """
         Send a keepalive to the client.
         """
 
-        packet = make_packet("ping")
-        self.transport.write(packet)
+        self.write_packet("ping")
 
     def error(self, message):
         """
@@ -359,8 +366,7 @@ class BetaServerProtocol(object, Protocol):
             raise BetaClientError("Invalid health value %d" % value)
 
         if self._health != value:
-            packet = make_packet("health", hp=value)
-            self.transport.write(packet)
+            self.write_packet("health", hp=value)
             self._health = value
 
 
@@ -384,15 +390,13 @@ class BetaProxyProtocol(BetaServerProtocol):
     gateway = "server.wiki.vg"
 
     def handshake(self, container):
-        packet = make_packet("handshake", username="-")
-        self.transport.write(packet)
+        self.write_packet("handshake", username="-")
 
     def login(self, container):
         self.username = container.username
 
-        packet = make_packet("login", protocol=0, username="", seed=0,
+        self.write_packet("login", protocol=0, username="", seed=0,
             dimension="earth")
-        self.transport.write(packet)
 
         url = urlunparse(("http", self.gateway, "/node/0/0/", None, None,
             None))
@@ -499,8 +503,8 @@ class BravoProtocol(BetaServerProtocol):
         for protocol in self.factory.protocols.itervalues():
             packet = protocol.player.save_to_packet()
             packet += protocol.player.save_equipment_to_packet()
-            packet += make_packet("create", eid=protocol.player.eid)
             self.transport.write(packet)
+            self.write_packet("create", eid=protocol.player.eid)
 
         self.factory.protocols[self.username] = self
 
@@ -647,23 +651,17 @@ class BravoProtocol(BetaServerProtocol):
             if command and command in commands:
                 def cb(iterable):
                     for line in iterable:
-                        self.transport.write(
-                            make_packet("chat", message=line)
-                        )
+                        self.write_packet("chat", message=line)
                 def eb(error):
-                    self.transport.write(
-                        make_packet("chat", message="Error: %s" %
-                                    error.getErrorMessage())
-                    )
+                    self.write_packet("chat", message="Error: %s" %
+                        error.getErrorMessage())
                 d = maybeDeferred(commands[command].chat_command,
                                   self.username, params)
                 d.addCallback(cb)
                 d.addErrback(eb)
             else:
-                self.transport.write(
-                    make_packet("chat",
-                        message="Unknown command: %s" % command)
-                )
+                self.write_packet("chat",
+                    message="Unknown command: %s" % command)
         else:
             # Send the message up to the factory to be chatified.
             message = "<%s> %s" % (self.username, container.message)
@@ -773,6 +771,27 @@ class BravoProtocol(BetaServerProtocol):
         dl = DeferredList(l)
         dl.addCallback(lambda none: self.factory.flush_chunk(chunk))
 
+    def select_for_inventory(self, block):
+        """
+        Perform a custom block selection to open an inventory window.
+
+        Returns whether the selection was successful.
+        """
+
+        if block == blocks["workbench"].slot:
+            i = Workbench()
+            i.wid = self.wid
+            self.wid += 1
+
+            sync_inventories(self.player.inventory, i)
+            self.windows.append(i)
+
+            self.write_packet("window-open", wid=i.wid, type="workbench",
+                title="Hurp", slots=2)
+            return True
+
+        return False
+
     @inlineCallbacks
     def build(self, container):
         if container.x == -1 and container.z == -1 and container.y == 255:
@@ -787,15 +806,8 @@ class BravoProtocol(BetaServerProtocol):
             self.error("Couldn't select in chunk (%d, %d)!" % (bigx, bigz))
             return
 
-        if (chunk.get_block((smallx, container.y, smallz)) ==
-            blocks["workbench"].slot):
-            i = Workbench()
-            sync_inventories(self.player.inventory, i)
-            self.windows[self.wid] = i
-            packet = make_packet("window-open", wid=self.wid, type="workbench",
-                title="Hurp", slots=2)
-            self.wid += 1
-            self.transport.write(packet)
+        if self.select_for_inventory(
+            chunk.get_block((smallx, container.y, smallz))):
             return
 
         # Ignore clients that think -1 is placeable.
@@ -928,32 +940,40 @@ class BravoProtocol(BetaServerProtocol):
         self.factory.broadcast_for_others(packet, self)
 
     def wclose(self, container):
-        if container.wid in self.windows:
-            i = self.windows[container.wid]
-            if i.identifier == 1:
+        top = self.windows.pop()
+
+        # If the requested WID is on top of the stack, go ahead and close the
+        # window. Otherwise, ignore it.
+        # XXX should/can we nak requests for closing windows?
+        if container.wid == top.wid:
+            if top.identifier == "workbench":
                 # Closing the workbench.
                 dest = self.location.in_front_of(1)
                 dest.y += 1
                 coords = (int(dest.x * 32) + 16, int(dest.y * 32) + 16,
                     int(dest.z * 32) + 16)
-                # loop over items left in workbench
-                for item in i.crafting:
+                # Loop over items left in workbench, and drop all of them
+                # in front of the player.
+                for item in top.crafting:
                     if item is None:
                         continue
                     self.factory.give(coords, (item[0], item[1]), item[2])
-            del self.windows[container.wid]
             sync_inventories(i, self.player.inventory)
+            # All done!
+            return
         elif container.wid == 0:
+            # XXX Why does this happen? What should we do?
             pass
         else:
-            self.error("Can't close non-existent window %d!" % container.wid)
+            log.msg("Ignoring request to close non-current window %d" %
+                container.wid)
 
     def waction(self, container):
         if container.wid == 0:
             # Inventory.
             i = self.player.inventory
-        elif container.wid in self.windows:
-            i = self.windows[container.wid]
+        elif self.windows and container.wid == self.windows[-1].wid:
+            i = self.windows[-1]
         else:
             self.error("Couldn't find window %d" % container.wid)
 
@@ -991,9 +1011,8 @@ class BravoProtocol(BetaServerProtocol):
                 )
                 self.factory.broadcast_for_others(packet, self)
 
-        packet = make_packet("window-token", wid=0, token=container.token,
+        self.write_packet("window-token", wid=0, token=container.token,
             acknowledged=selected)
-        self.transport.write(packet)
 
     def sign(self, container):
         bigx, smallx, bigz, smallz = split_coords(container.x, container.z)
@@ -1034,11 +1053,9 @@ class BravoProtocol(BetaServerProtocol):
         chunk = self.chunks.pop(x, z)
 
         for entity in chunk.entities:
-            packet = make_packet("destroy", eid=entity.eid)
-            self.transport.write(packet)
+            self.write_packet("destroy", eid=entity.eid)
 
-        packet = make_packet("prechunk", x=x, z=z, enabled=0)
-        self.transport.write(packet)
+        self.write_packet("prechunk", x=x, z=z, enabled=0)
 
     def enable_chunk(self, x, z):
         """
@@ -1060,8 +1077,7 @@ class BravoProtocol(BetaServerProtocol):
         return d
 
     def send_chunk(self, chunk):
-        packet = make_packet("prechunk", x=chunk.x, z=chunk.z, enabled=1)
-        self.transport.write(packet)
+        self.write_packet("prechunk", x=chunk.x, z=chunk.z, enabled=1)
 
         packet = chunk.save_to_packet()
         self.transport.write(packet)
@@ -1099,9 +1115,10 @@ class BravoProtocol(BetaServerProtocol):
 
         # Send the MOTD.
         if self.motd:
-            packet = make_packet("chat",
-                message=self.motd.replace("<tagline>", get_motd()))
-            d.addCallback(lambda none: self.transport.write(packet))
+            @d.addCallback
+            def cb(none):
+                self.write_packet("chat",
+                    message=self.motd.replace("<tagline>", get_motd()))
 
         # Finally, start the secondary chunk loop.
         d.addCallback(lambda none: self.update_chunks())
@@ -1149,8 +1166,7 @@ class BravoProtocol(BetaServerProtocol):
         ]
 
     def update_time(self):
-        packet = make_packet("time", timestamp=int(self.factory.time))
-        self.transport.write(packet)
+        self.write_packet("time", timestamp=int(self.factory.time))
 
     def connectionLost(self, reason):
         if self.time_loop:
