@@ -1,5 +1,6 @@
 from twisted.application.internet import TCPClient, TCPServer
 from twisted.application.service import Application, MultiService
+from twisted.application.strports import service as serviceForEndpoint
 from twisted.internet.protocol import Factory
 from twisted.python import log
 
@@ -16,6 +17,16 @@ class BetaProxyFactory(Factory):
         self.name = name
         self.port = configuration.getint("infiniproxy %s" % name, "port")
 
+def services_for_endpoints(endpoints, factory):
+    l = []
+    for endpoint in endpoints:
+        server = serviceForEndpoint(endpoint, factory)
+        # XXX hack for bravo.web:135, which wants this. :c
+        server.args = [None, factory]
+        server.setName("%s (%s)" % (factory.name, endpoint))
+        l.append(server)
+    return l
+
 class BravoService(MultiService):
 
     def __init__(self):
@@ -40,11 +51,13 @@ class BravoService(MultiService):
 
         for section in configuration.sections():
             if section.startswith("world "):
+                # Bravo worlds. Grab a list of endpoints and load them.
                 factory = BravoFactory(section[6:])
-                server = TCPServer(factory.port, factory,
-                    interface=factory.interface)
-                server.setName(factory.name)
-                self.addService(server)
+                interfaces = configuration.getlist(section, "interfaces")
+
+                for service in services_for_endpoints(interfaces, factory):
+                    self.addService(service)
+
                 self.factorylist.append(factory)
             elif section == "web":
                 try:
@@ -53,10 +66,11 @@ class BravoService(MultiService):
                     log.msg("Couldn't import web stuff!")
                 else:
                     factory = bravo_site(self.namedServices)
-                    port = configuration.getint("web", "port")
-                    server = TCPServer(port, factory)
-                    server.setName("web")
-                    self.addService(server)
+                    factory.name = "web"
+                    interfaces = configuration.getlist("web", "interfaces")
+
+                    for service in services_for_endpoints(interfaces, factory):
+                        self.addService(service)
             elif section.startswith("irc "):
                 try:
                     from bravo.irc import BravoIRC
@@ -67,20 +81,23 @@ class BravoService(MultiService):
                     self.ircbots.append(section)
             elif section.startswith("infiniproxy "):
                 factory = BetaProxyFactory(section[12:])
-                server = TCPServer(factory.port, factory)
-                server.setName(factory.name)
-                self.addService(server)
+                interfaces = configuration.getlist(section, "interfaces")
+
+                for service in services_for_endpoints(interfaces, factory):
+                    self.addService(service)
             elif section.startswith("infininode "):
                 factory = InfiniNodeFactory(section[11:])
-                server = TCPServer(factory.port, factory)
-                server.setName(factory.name)
-                self.addService(server)
+                interfaces = configuration.getlist(section, "interfaces")
+
+                for service in services_for_endpoints(interfaces, factory):
+                    self.addService(service)
         if self.irc:
             for section in self.ircbots:
                 factory = BravoIRC(self.factorylist, section[4:])
                 client = TCPClient(factory.host, factory.port, factory)
                 client.setName(factory.config)
                 self.addService(client)
+
 service = BravoService()
 
 application = Application("Bravo")
